@@ -195,7 +195,7 @@ def main():
         exit(return_code)
 
 
-def analyze(source_code, canvas_size=None):
+def analyze_live_python(source_code, canvas_size=None):
     """ Trace the source code for display in the browser.
 
     :param source_code: Source code to trace.
@@ -228,7 +228,7 @@ def analyze(source_code, canvas_size=None):
 
 
 def web_main():
-    window.analyze = analyze
+    window.analyzeLivePython = analyze_live_python
 
 
 class StandardFiles(dict):
@@ -256,7 +256,7 @@ class StandardFiles(dict):
             file_key = (filename, mode)
             file = self.new_files.get(file_key)
             if file is None:
-                file = argparse.FileType(mode)(filename)
+                file = open(filename, mode)
                 self.new_files[file_key] = file
         super().__setitem__(key, file)
 
